@@ -14,34 +14,23 @@ module.exports = function(grunt) {
         }
       }
     },
-    jshint: {
+    eslint: {
       gruntfile_tasks: ['Gruntfile.js', 'internal-tasks/*.js'],
       libs_n_tests: ['lib/**/*.js', '<%= nodeunit.all %>'],
-      subgrunt: ['<%= subgrunt.all %>'],
-      options: {
-        jshintrc: '.jshintrc'
-      }
-    },
-    jscs: {
-      src: [
-        'lib/**/*.js',
-        'internal-tasks/**/*.js',
-        'test/**/*.js',
-        '!test/fixtures/**/*.js'
-      ]
+      subgrunt: ['<%= subgrunt.all %>']
     },
     watch: {
       gruntfile_tasks: {
-        files: ['<%= jshint.gruntfile_tasks %>'],
-        tasks: ['jshint:gruntfile_tasks']
+        files: ['<%= eslint.gruntfile_tasks %>'],
+        tasks: ['eslint:gruntfile_tasks']
       },
       libs_n_tests: {
-        files: ['<%= jshint.libs_n_tests %>'],
-        tasks: ['jshint:libs_n_tests', 'nodeunit']
+        files: ['<%= eslint.libs_n_tests %>'],
+        tasks: ['eslint:libs_n_tests', 'nodeunit']
       },
       subgrunt: {
         files: ['<%= subgrunt.all %>'],
-        tasks: ['jshint:subgrunt', 'subgrunt']
+        tasks: ['eslint:subgrunt', 'subgrunt']
       }
     },
     subgrunt: {
@@ -50,8 +39,7 @@ module.exports = function(grunt) {
   });
 
   // These plugins provide necessary tasks.
-  grunt.loadNpmTasks('grunt-contrib-jshint');
-  grunt.loadNpmTasks('grunt-jscs');
+  grunt.loadNpmTasks('grunt-eslint');
   grunt.loadNpmTasks('grunt-contrib-nodeunit');
   grunt.loadNpmTasks('grunt-contrib-watch');
 
@@ -60,7 +48,7 @@ module.exports = function(grunt) {
 
   // "npm test" runs these tasks
   grunt.registerTask('test', '', function(reporter) {
-    grunt.task.run(['jshint', 'jscs', 'nodeunit:' + (reporter || 'all'), 'subgrunt']);
+    grunt.task.run(['eslint', 'nodeunit:' + (reporter || 'all'), 'subgrunt']);
   });
 
   // Default task.
